@@ -10,7 +10,9 @@ StatBraceLabel <- ggplot2::ggproto(
     distance = NULL,
     outerstart = NULL,
     width = NULL,
-    outside = TRUE
+    outside = TRUE,
+    bending = NULL,
+    discreteAxis=FALSE
   ){
       x = data$x
       y = data$y
@@ -25,7 +27,9 @@ StatBraceLabel <- ggplot2::ggproto(
         distance = distance,
         outerstart = outerstart,
         width = width,
-        outside = outside
+        outside = outside,
+        bending = bending,
+        discreteAxis = discreteAxis
       )[["labelCoords"]]
 
       return(coords)
